/*
 * Copyright (C) 2019-2024 CZ.NIC z.s.p.o. (https://www.nic.cz/)
 *
 * This is free software, licensed under the GNU General Public License v3.
 * See /LICENSE for more information.
 */

import React from "react";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import {
    faAngleLeft,
    faAnglesLeft,
    faAngleRight,
    faAnglesRight,
} from "@fortawesome/free-solid-svg-icons";

const RichTablePagination = ({ table, tablePageSize }) => {
    const prevPagBtnDisabled = !table.getCanPreviousPage();
    const nextPagBtnDisabled = !table.getCanNextPage();

    return (
        <nav
            aria-label={_("Pagination navigation bar")}
            className="d-flex gap-2 justify-content-start align-items-center mx-2 mb-1 text-nowrap"
        >
            <ul className="pagination pagination-sm mb-0">
                <li
                    className={`page-item ${prevPagBtnDisabled ? "disabled" : ""}`.trim()}
                    style={
                        prevPagBtnDisabled
                            ? { cursor: "not-allowed" }
                            : { cursor: "pointer" }
                    }
                >
                    <button
                        className="page-link"
                        aria-label={_("First page")}
                        onClick={() => table.firstPage()}
                        disabled={prevPagBtnDisabled}
                    >
                        <FontAwesomeIcon icon={faAnglesLeft} />
                    </button>
                </li>
                <li
                    className={`page-item ${prevPagBtnDisabled ? "disabled" : ""}`.trim()}
                    style={
                        prevPagBtnDisabled
                            ? { cursor: "not-allowed" }
                            : { cursor: "pointer" }
                    }
                >
                    <button
                        className="page-link"
                        aria-label={_("Previous page")}
                        onClick={() => table.previousPage()}
                        disabled={prevPagBtnDisabled}
                    >
                        <FontAwesomeIcon icon={faAngleLeft} />
                    </button>
                </li>
                <li
                    className={`page-item ${nextPagBtnDisabled ? "disabled" : ""}`.trim()}
                    style={
                        nextPagBtnDisabled
                            ? { cursor: "not-allowed" }
                            : { cursor: "pointer" }
                    }
                >
                    <button
                        className="page-link"
                        aria-label={_("Next page")}
                        onClick={() => table.nextPage()}
                        disabled={nextPagBtnDisabled}
                    >
                        <FontAwesomeIcon icon={faAngleRight} />
                    </button>
                </li>
                <li
                    className={`page-item ${nextPagBtnDisabled ? "disabled" : ""}`.trim()}
                    style={
                        nextPagBtnDisabled
                            ? { cursor: "not-allowed" }
                            : { cursor: "pointer" }
                    }
                >
                    <button
                        className="page-link"
                        aria-label={_("Last page")}
                        onClick={() => table.lastPage()}
                        disabled={nextPagBtnDisabled}
                    >
                        <FontAwesomeIcon icon={faAnglesRight} />
                    </button>
                </li>
            </ul>
            <span>
                {_("Page")}&nbsp;
                <span className="fw-bold">
                    {table.getState().pagination.pageIndex + 1}
                    &nbsp;{_("of")}&nbsp;
                    {table.getPageCount().toLocaleString()}
                </span>
            </span>
            <div
                className="vr mx-1 align-self-center"
                style={{ height: "1.5rem" }}
            />
            <span>
                {_("Go to page:")}
                <div className="d-inline-block ms-1 input-group input-group-sm w-auto">
                    <input
                        type="number"
                        min="1"
                        max={table.getPageCount()}
                        defaultValue={table.getState().pagination.pageIndex + 1}
                        onChange={(e) => {
                            const page = e.target.value
                                ? Number(e.target.value) - 1
                                : 0;
                            table.setPageIndex(page);
                        }}
                        className="form-control w-auto"
                        aria-label={_("Page number")}
                    />
                </div>
            </span>
            <select
                className="form-select form-select-sm w-auto"
                aria-label={_("Select page size")}
                value={table.getState().pagination.pageSize}
                onChange={(e) => {
                    table.setPageSize(Number(e.target.value));
                }}
            >
                {[
                    // if tablePageSize is not in the list, add it
                    tablePageSize === 10 ? null : tablePageSize,
                    10,
                    20,
                    30,
                    40,
                    50,
                ].map((pageSize) => (
                    <option key={pageSize} value={pageSize}>
                        {_("Show")} {pageSize}
                    </option>
                ))}
            </select>
        </nav>
    );
};

export default RichTablePagination;
